@@ -22,16 +22,16 @@ class CurrencyAdmin(admin.ModelAdmin):
 
 
 class SandBoxAdmin(admin.ModelAdmin):
-    fields = ('id', 'sand_box_name', 'sand_box_label', 'description')
-    list_display = ('id', 'sand_box_name', 'sand_box_label', 'description')
-    search_fields = ('id', 'sand_box_name', 'sand_box_label', 'description')
+    fields = ('id', 'sand_box_name', 'sand_box_label', 'description', 'config')
+    list_display = ('id', 'sand_box_name', 'sand_box_label', 'description', 'config')
+    search_fields = ('id', 'sand_box_name', 'sand_box_label', 'description', 'config')
     readonly_fields = ['id']
 
 
 class StatusCodeAdmin(admin.ModelAdmin):
-    fields = ('id', 'finance_status_code', 'description',)
-    list_display = ('id', 'finance_status_code', 'description',)
-    search_fields = ('id', 'finance_status_code', 'description',)
+    fields = ('id', 'finance_status_code', 'finance_status_name', 'description',)
+    list_display = ('id', 'finance_status_code', 'finance_status_name', 'description',)
+    search_fields = ('id', 'finance_status_code', 'finance_status_name', 'description',)
     readonly_fields = ['id']
 
 
