@@ -13,9 +13,12 @@ from django.forms import model_to_dict
 from django.utils import timezone
 from django.utils.datetime_safe import datetime
 import pytz
+from numpy.core.defchararray import upper
 from rest_framework import serializers
 from main.settings import BASE_DIR
+from xj_thread.services.thread_item_service import ThreadItemService
 from xj_user.models import BaseInfo
+from xj_user.services.user_detail_info_service import DetailInfoService
 from xj_user.services.user_platform_service import UserPlatformService
 from .finance_service import FinanceService
 from ..models import Transact, Currency, PayMode, SandBox, StatusCode
@@ -216,8 +219,10 @@ class FinanceTransactService:
         pay_mode = params.get("pay_mode", None)
         goods_info = params.get("goods_info", None)
         sand_box_status_code = params.get("sand_box_status_code", None)
+        sand_box = params.get("sand_box", None)
         currency = params.get("currency", "CNY")
         images = params.get("images", "")
+        action = params.get("action", "支付")
         user_finance_data = {
             'account_id': account_id,
             'their_account_name': sub_appid,
@@ -245,42 +250,76 @@ class FinanceTransactService:
         if order_no:
             user_finance_data['order_no'] = order_no
             platform_finance_data['order_no'] = order_no
-        if summary:
-            summary_content = "【" + summary['payer'] + "】支付 【" + summary['payee'] + "】项目名称【" + summary[
-                'entry_name'] + "】款项"
-            user_finance_data['summary'] = summary_content
-            platform_finance_data['summary'] = summary_content
-        #
+        else:
+            user_finance_data['order_no'] = FinanceService.make_unicode()
+            platform_finance_data['order_no'] = FinanceService.make_unicode()
+
+        if not transact_no:
+            transact_no = FinanceService.make_unicode(user_finance_data['order_no'])
+
+        if sand_box:
+            user_finance_data['sand_box'] = sand_box  # 沙盒应付
+            platform_finance_data['sand_box'] = sand_box  # 沙盒应付
+        # 生成摘要
+        user_set, err = DetailInfoService.get_detail(account_id)
+        user_platform_set, platform_err = DetailInfoService.get_detail(search_params={"nickname": sub_appid})
+        project_name = None
+        # 用户报名通知代码块
+        if user_set:
+            if enroll_id:
+                # 如果存在报名id 查询报名记录
+                if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
+                    from xj_enroll.service.enroll_services import EnrollServices
+                enroll_set, enroll_err = EnrollServices.enroll_detail(enroll_id)
+                if enroll_set:
+                    # 根据报名记录获取 信息模块项目基本信息
+                    thread_set, thread_err = ThreadItemService.detail(enroll_set['thread_id'])
+                    if thread_set:
+                        project_name = thread_set['title']
+        summary_content = "【" + user_set['full_name'] + "】" + action + "【" + user_platform_set[
+            'full_name'] + "】项目名称【" + project_name + "】款项"
+
+        user_finance_data['summary'] = summary_content
+        platform_finance_data['summary'] = summary_content
+
         if goods_info:
             user_finance_data['goods_info'] = goods_info
             platform_finance_data['goods_info'] = goods_info
         if sand_box_status_code:
-            user_finance_data['sand_box_status_code'] = sand_box_status_code
-            platform_finance_data['sand_box_status_code'] = sand_box_status_code
+            user_finance_data['sand_box_status_code'] = str(upper(sand_box_status_code))
+            platform_finance_data['sand_box_status_code'] = str(upper(sand_box_status_code))
+
         if images:
             user_finance_data['images'] = images
             platform_finance_data['images'] = images
 
-        if finance_type == "RECHARGE":  # 充值行为
+        # 充值行为（线上支付 生成真实记录）|转账行为（线下支付 生成沙盒记录 审核成功后核销沙盒 生成真实记录）
+        if finance_type == "RECHARGE" or finance_type == "TRANSFER":
             try:
+                if finance_type == "TRANSFER":
+                    user_finance_data['sand_box'] = sand_box_meet  # 沙盒应付
+                    platform_finance_data['sand_box'] = sand_box_receivable  # 沙盒应收
+
                 user_finance_data['amount'] = -abs(float(amount))
                 user_finance_data['transact_no'] = str(transact_no) + "-1"
                 user_finance_data['finance_status_name'] = "待接单"  # 资金状态码 finance_status_code 43 已下单支付 待接单
+                # user_finance_data['money_flow'] = "TRANSFER"  # 资金流行为
                 user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
                 if user_err_txt:
-                    print(">>>>payment_logic_processing_err", user_err_txt)
+                    # print(">>>>payment_logic_processing_err", user_err_txt)
                     # logger.info(">>>>payment_logic_processing" + "写入资金模块失败")
                     return None, user_err_txt
                 platform_finance_data['amount'] = float(amount)
                 platform_finance_data['transact_no'] = str(transact_no) + "-2"
                 platform_finance_data['finance_status_name'] = "待接单"  # 资金状态码 finance_status_code 43 已下单支付 待接单
+                # platform_finance_data['money_flow'] = "TRANSFER"  # 沙盒应收
                 finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
                 if err_txt:
                     return None, err_txt
-                return None, None
+                return user_finance_data['order_no'], None
             except Exception as e:
                 return None, str(e)
-
+        # 支付行为 （由平台对用户进行余额转账）
         elif finance_type == "PAY":  # 支付行为
             try:
                 user_finance_data['sand_box'] = sand_box_receivable  # 沙盒应收
@@ -289,7 +328,6 @@ class FinanceTransactService:
                 user_finance_data['transact_no'] = FinanceService.make_unicode(str(user_finance_data['account_id']))
                 user_finance_data['finance_status_name'] = "待付款"  # 资金状态码 finance_status_code 242 报名成功 待付款
                 user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
-                # print(user_finance_data)
                 if user_err_txt:
                     return None, user_err_txt
                 platform_finance_data['sand_box'] = sand_box_meet  # 沙盒应付
@@ -301,19 +339,21 @@ class FinanceTransactService:
                 finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
                 if err_txt:
                     return None, err_txt
-                return None, None
+                return user_finance_data['order_no'], None
+
             except Exception as e:
                 return None, str(e)
-        elif finance_type == "WITHDRAW":  # 提现行为
+        # 提现行为
+        elif finance_type == "WITHDRAW":
             user_finance_data['sand_box'] = sand_box_cash_withdrawal  # 提现
             user_finance_data['amount'] = -abs(float(amount))
             user_finance_data['order_no'] = FinanceService.make_unicode()
             finance_add_data, err_txt = FinanceTransactService.post(user_finance_data)
             if err_txt:
                 return None, None
-            return None, None
+            return user_finance_data['order_no'], None
         else:
-            return None, "资金类型不存在"
+            return order_no, "资金类型不存在"
 
     @staticmethod
     def post(param):
@@ -457,9 +497,9 @@ class FinanceTransactService:
             outgo = Decimal(math.fabs(amount)) if amount < 0 else Decimal(0.0)
             item['outgo'] = outgo
         else:
-            income = Decimal(param.get('income ', 0.0))
+            income = float(param.get('income', 0.0))
             item['income'] = income
-            outgo = Decimal(param.get('outgo', 0.0))
+            outgo = float(param.get('outgo', 0.0))
             item['outgo'] = outgo
 
         enroll_id = param.get('enroll_id', '')
@@ -518,6 +558,7 @@ class FinanceTransactService:
             item['thread_id'] = thread_id
         # 快照
         goods_info = param.get('goods_info', '')
+        # print(goods_info)
         if goods_info:
             jsDumps = json.dumps(goods_info, cls=DateEncoder)
             jsLoads = json.loads(jsDumps)
@@ -526,16 +567,16 @@ class FinanceTransactService:
                 if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
                     from xj_enroll.service.enroll_services import EnrollServices
                 if isinstance(goods_info['enroll'], dict):
-                    EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoicing"},
+                    EnrollServices.enroll_edit(params={"finance_invoicing_code": "INVOICING"},
                                                search_param={"enroll_id": goods_info['enroll']['id']})
                 else:
                     for i in goods_info['enroll']:
                         enroll_list.append(int(i['id']))
-                    EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoicing"},
+                    EnrollServices.enroll_edit(params={"finance_invoicing_code": "INVOICING"},
                                                search_param={"enroll_id_list": enroll_list})
-            else:
-                print('不存在')
-        item['goods_info'] = jsLoads
+            # else:
+            #     print('不存在')
+            item['goods_info'] = jsLoads
 
         # 如果有沙盒。
         if item['sand_box']:
@@ -548,7 +589,7 @@ class FinanceTransactService:
 
         item['balance'] = last_balance
         if item['pay_mode_set'].pay_mode == "BALANCE":
-            balance = last_balance + income - outgo
+            balance = float(last_balance) + float(income) - float(outgo)
             item['balance'] = balance
 
         # 平台订单号是可以允许重复的，如果没有平台订单号则输入交易号
@@ -565,11 +606,11 @@ class FinanceTransactService:
         if summary:
             item['summary'] = summary
         elif not summary and param.get("sand_box_status_code", ""):
-            if param.get("sand_box_status_code", "") == "Invoicing":
+            if param.get("sand_box_status_code", "") == "INVOICING":
                 item['summary'] = "开票"
-            elif param.get("sand_box_status_code", "") == "withdrawing":
+            elif param.get("sand_box_status_code", "") == "WITHDRAWING":
                 item['summary'] = "提现"
-            elif param.get("sand_box_status_code", "") == "transfering":
+            elif param.get("sand_box_status_code", "") == "TRANSFERING":
                 item['summary'] = "转账"
 
         # # 商品信息
@@ -674,7 +715,6 @@ class FinanceTransactService:
         serializer.validated_data['goods_info'] = item.get('goods_info', None)
         serializer.validated_data['images'] = item.get('images', None)
 
-
         # print(">>> serializer.validated_data: ", serializer.validated_data,)
         # print(">>> serializer: ", serializer,)
 
