@@ -1,32 +1,26 @@
-import json
-import re
-import sys
 from decimal import Decimal
-import random
-from tkinter import E
-
-import pytz
-from django.core.paginator import Paginator
-from django.db.models import Q, Sum, F
-from django.forms import model_to_dict
-from rest_framework import serializers
+import json
+from logging import getLogger
 from pathlib import Path
-from main.settings import BASE_DIR
+import sys
 
+from django.db.models import Sum
+from django.forms import model_to_dict
+import pytz
+from rest_framework import serializers
+
+from main.settings import BASE_DIR
 from xj_enroll.utils.custom_tool import format_params_handle
-from xj_finance.services.finance_transact_service import FinanceTransactService, DateEncoder
+from xj_finance.services.finance_transact_service import FinanceTransactService
 from xj_finance.utils.custom_tool import filter_result_field
+from xj_thread.services.thread_list_service import ThreadListService
 from xj_thread.utils.join_list import JoinList
 from xj_user.models import BaseInfo
 from xj_user.services.user_platform_service import UserPlatformService
-from xj_thread.services.thread_list_service import ThreadListService
 from .finance_service import FinanceService
 from ..models import Transact, PayMode
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
-from logging import getLogger
-import json as default_json
-from json.encoder import JSONEncoder
 
 logger = getLogger('log')
 
@@ -613,24 +607,29 @@ class FinanceTransactsService:
         transact_obj = Transact.objects
         list = []
         for i in enroll_id_list:
-            transact_set = transact_obj.filter(enroll_id=i, sand_box__isnull=True, ).order_by("-id").first()
-            if not transact_set:
-                continue
-            finance_data = transact_set.to_dict()
-            pay_mode = PayMode.objects.filter(id=finance_data['pay_mode']).first()
-            pay_mode_data = model_to_dict(pay_mode)
             standing_book = {}
             standing_book['enroll_id'] = i  # 报名ID
             standing_book['billing_time'] = None  # 开票时间
-            standing_book['charge_time'] = finance_data['transact_time']  # 收款时间时间
-            standing_book['charge_mode'] = pay_mode_data['pay_mode']  # 收款方式
+            standing_book['charge_time'] = None  # 收款时间时间
+            standing_book['charge_mode'] = None  # 收款方式
             standing_book['payment_time'] = None  # 付款时间 （暂无）
             standing_book['payment_delay'] = None  # 付款方式（暂无）
             standing_book['billing_time'] = None  # 开票时间
 
+            transact_set = transact_obj.filter(enroll_id=i, sand_box__isnull=True, ).order_by("-id").first()
+            if not transact_set:
+                list.append(standing_book)
+                continue
+
+            finance_data = transact_set.to_dict()
+            pay_mode = PayMode.objects.filter(id=finance_data['pay_mode']).first()
+            pay_mode_data = model_to_dict(pay_mode)
+            standing_book['charge_time'] = finance_data['transact_time']  # 收款时间时间
+            standing_book['charge_mode'] = pay_mode_data['pay_mode']  # 收款方式
+
             invoice_set = transact_obj.filter(
-                sand_box__sand_box_name__in=["BID_SPECIAL_INVOICE", "BID_PLAIN_INVOICE"], ).order_by("-id").values(
-                "goods_info")
+                sand_box__sand_box_name__in=["BID_SPECIAL_INVOICE", "BID_PLAIN_INVOICE"]
+            ).order_by("-id").values("goods_info")
             if not invoice_set:
                 continue
             for item in (invoice_set):
@@ -659,7 +658,4 @@ class FinanceTransactsService:
             standing_book['invoiced_amount'] = abs(invoiced_amount)  # 发票金额
             list.append(standing_book)
 
-        if list:
-            return list, None
-        else:
-            return {"status": "0"}, None
+        return list, None
