@@ -30,12 +30,14 @@ urlpatterns = [
     re_path(r'^balance/?$', FinanceBalance.as_view(), ),
     re_path(r'^distribution/?$', FinanceTransacts.distribution, ),
     re_path(r'^write_off/?$', FinanceTransacts.write_off, ),
+    re_path(r'^large_amount_audit/?$', FinanceTransacts.large_amount_audit, ),
     re_path(r'^invoicing_approval/?$', FinanceTransacts.invoicing_approval, ),
+    re_path(r'^create_or_write_off/?$', FinanceTransacts.create_or_write_off, ),
     re_path(r'^large_transfer/?$', FinanceTransacts.large_transfer, ),
     re_path(r'^flow_writing/?$', FinanceTransact.finance_flow_writing, ),
     re_path(r'^cash_withdrawal/?$', FinanceBalance.cash_withdrawal, ),
     re_path(r'^status_code/?$', FinanceStatusCode.as_view(), ),
-
+    re_path(r'^standing_book/?$', FinanceTransact.finance_standing_book, ),
     # 该功能已使用finance_transact的POST方法代替
     # re_path(r'^_transact_add/?$', finance_transact_add.FinanceTransactAdd.as_view(), ),
     #
